# -*- coding: utf-8 -*-
from design.plone.contenttypes.controlpanels.settings import (
    IDesignPloneSettings,
)
from plone import api
from uuid import uuid4

import logging
import json
import six


logger = logging.getLogger(__name__)


def get_settings_for_language(field):
    values = api.portal.get_registry_record(
        field, interface=IDesignPloneSettings, default=[]
    )
    if not values:
        return []
    if not isinstance(values, six.text_type):
        return values
    try:
        json_data = json.loads(values)
    except Exception as e:
        logger.exception(e)
        return values
    lang = api.portal.get_current_language()
    return json_data.get(lang, [])


def create_default_blocks(context):
    title_uuid = str(uuid4())
    context.blocks = {title_uuid: {"@type": "title"}}
    context.blocks_layout = {"items": [title_uuid]}



# -*- coding: utf-8 -*-
from plone import api
from redturtle.bandi.interfaces.settings import IBandoSettings
from Products.CMFPlone.interfaces import INonInstallable
from zope.interface import implementer


@implementer(INonInstallable)
class HiddenProfiles(object):
    def getNonInstallableProfiles(self):
        """Hide uninstall profile from site-creation and quickinstaller."""
        return [
            "design.plone.contenttypes:uninstall",
            "design.plone.contenttypes:to_3000",
        ]


def post_install(context):
    """Post install script"""

    remove_blocks_behavior(context)

    portal_types = api.portal.get_tool(name="portal_types")
    # add image fields at the end of document behaviors and remove tableofcontents
    document_behaviors = [
        x
        for x in portal_types["Document"].behaviors
        if x
        not in [
            "plone.leadimage",
            "volto.preview_image",
            "plone.tableofcontents",
        ]
    ]
    document_behaviors.extend(["plone.leadimage", "volto.preview_image"])
    portal_types["Document"].behaviors = tuple(document_behaviors)

    # remove default ente
    api.portal.set_registry_record("default_ente", (), interface=IBandoSettings)


def remove_blocks_behavior(context):
    portal_types = api.portal.get_tool(name="portal_types")
    for ptype in ["News Item", "Event"]:
        portal_types[ptype].behaviors = tuple(
            [x for x in portal_types[ptype].behaviors if x != "volto.blocks"]
        )


def uninstall(context):
    """Uninstall script"""
    # Do something at the end of the uninstallation of this package.



# -*- coding: utf-8 -*-
from .dxcontent import SerializeFolderToJson as BaseSerializer
from design.plone.contenttypes.interfaces.servizio import IServizio
from plone import api
from plone.restapi.interfaces import ISerializeToJson
from zope.component import adapter
from zope.interface import implementer
from zope.interface import Interface
from plone.restapi.interfaces import ISerializeToJsonSummary
from plone.restapi.serializer.converters import json_compatible
from zope.component import getMultiAdapter


class SerializeFolderToJson(BaseSerializer):
    def __call__(self, version=None, include_items=True):
        # if include_items:
        #     self.request.form = {"fullobjects": ""}
        result = super(SerializeFolderToJson, self).__call__(
            version=version, include_items=include_items
        )

        catalog = api.portal.get_tool("portal_catalog")
        limit = 3
        query = {
            self.index: result["UID"],
            "portal_type": ["News Item"],
            "sort_on": "effective",
            "sort_order": "descending",
            "sort_limit": limit,
        }
        brains = catalog(**query)[:limit]
        result["related_news"] = [self.serialize_brain(x) for x in brains]
        return result

    def serialize_brain(self, brain):
        data = getMultiAdapter((brain, self.request), ISerializeToJsonSummary)()
        if brain.effective.Date() != "1969/12/31":
            data["effective"] = json_compatible(brain.effective)
        else:
            data["effective"] = None
        data["typology"] = brain.tipologia_notizia or ""

        return data


@implementer(ISerializeToJson)
@adapter(IServizio, Interface)
class ServizioSerializer(SerializeFolderToJson):
    index = "news_service"



# -*- coding: utf-8 -*-

from design.plone.contenttypes.testing import (
    DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING,
)
from plone import api
import unittest


class TestDocument(unittest.TestCase):
    layer = DESIGN_PLONE_CONTENTTYPES_INTEGRATION_TESTING

    def setUp(self):
        """Custom shared utility setup for tests."""
        self.portal = self.layer["portal"]

    def test_behaviors_enabled_for_documento_personale(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual(
            portal_types["Documento Personale"].behaviors,
            (
                "plone.namefromtitle",
                "plone.allowdiscussion",
                "plone.excludefromnavigation",
                "plone.shortname",
                "plone.ownership",
                "plone.publication",
                "plone.categorization",
                "plone.basic",
                "design.plone.contenttypes.behavior.descrizione_estesa",
                "design.plone.contenttypes.behavior.additional_help_infos",
                "plone.locking",
            ),
        )

    def test_document_ct_title(self):
        portal_types = api.portal.get_tool(name="portal_types")
        self.assertEqual("Documento", portal_types["Documento"].title)
